@@ -125,7 +125,13 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
     {
         parent::initialize();
 
-        foreach ($this->getUrlMatches() as $url) {
+        $urlMatches = $this->getUrlMatches();
+
+        if (empty($urlMatches)) {
+            throw new \RuntimeException('The `url` supplied for the path (' . $this->url . ') repository does not exist');
+        }
+
+        foreach ($urlMatches as $url) {
             $path = realpath($url) . DIRECTORY_SEPARATOR;
             $composerFilePath = $path.'composer.json';
 
@@ -153,15 +159,26 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
                 }
             }
 
-            if (!isset($package['version'])) {
-                $versionData = $this->versionGuesser->guessVersion($package, $path);
-                $package['version'] = $versionData['pretty_version'] ?: 'dev-master';
-            }
-
             $output = '';
             if (is_dir($path . DIRECTORY_SEPARATOR . '.git') && 0 === $this->process->execute('git log -n1 --pretty=%H', $output, $path)) {
                 $package['dist']['reference'] = trim($output);
             }
+
+            if (!isset($package['version'])) {
+                $versionData = $this->versionGuesser->guessVersion($package, $path);
+                if (is_array($versionData) && $versionData['pretty_version']) {
+                    // if there is a feature branch detected, we add a second packages with the feature branch version
+                    if (!empty($versionData['feature_pretty_version'])) {
+                        $package['version'] = $versionData['feature_pretty_version'];
+                        $this->addPackage($this->loader->load($package));
+                    }
+
+                    $package['version'] = $versionData['pretty_version'];
+                } else {
+                    $package['version'] = 'dev-master';
+                }
+            }
+
             $package = $this->loader->load($package);
             $this->addPackage($package);
         }
